@@ -21,6 +21,7 @@
 #define __TOTEM_H__
 
 #include <gconf/gconf-client.h>
+#include <gtk/gtkwindow.h>
 #include "bacon-video-widget.h"
 
 #define TOTEM_GCONF_PREFIX "/apps/totem"
@@ -28,7 +29,7 @@
 typedef struct Totem Totem;
 
 void	totem_action_exit			(Totem *totem);
-void	totem_action_play			(Totem *totem, int offset);
+void	totem_action_play			(Totem *totem);
 void	totem_action_stop			(Totem *totem);
 void	totem_action_play_pause			(Totem *totem);
 void	totem_action_fullscreen_toggle		(Totem *totem);
@@ -45,6 +46,8 @@ void	totem_action_play_media			(Totem *totem, MediaType type);
 
 void	totem_action_toggle_aspect_ratio	(Totem *totem);
 void	totem_action_set_scale_ratio		(Totem *totem, gfloat ratio);
+void    totem_action_error                      (char *title, char *reason,
+						 Totem *totem);
 
 GConfClient *totem_get_gconf_client		(Totem *totem);
 
